@@ -2,6 +2,7 @@ try:
     from collections.abc import Iterable
 except ImportError:
     from collections import Iterable
+
 from typing import TYPE_CHECKING, List, Tuple, Type, TypeVar, Union
 
 try:
@@ -18,9 +19,6 @@ from django.contrib.auth.models import AbstractUser, AnonymousUser
 from django.db import models
 from django.db.models.query import QuerySet
 
-if TYPE_CHECKING:  # pragma: nocover
-    from guardian.core import ObjectPermissionChecker  # noqa: F811
-
 _T = TypeVar("_T", bound="GuardedModel")
 _TR = TypeVar("_TR", bound="GuardedRelatedModel")
 
@@ -48,6 +46,8 @@ def _has_anonymous_user():
 class GuardedModelManager(models.Manager[_T]):
     """Model manager that integrates with guardian to check for permissions."""
 
+    model: Type[_T]
+
     def for_user(
         self,
         user: Union[AbstractUser, AnonymousUser],
@@ -155,16 +155,23 @@ class GuardedModel(models.Model):
     class Meta:
         abstract = True
 
-    # NOTE: This should be adjusted in each model using this class
-    # for better typing support
-    objects = GuardedModelManager["GuardedModel"]()
+    # Make sure objects is properly typed for subclasses
+    if TYPE_CHECKING:
+
+        @classmethod
+        @property
+        def objects(cls: Type[_T]) -> GuardedModelManager[_T]:
+            ...
+
+    else:
+        objects = GuardedModelManager["GuardedModel"]()
 
     def has_perm(
         self,
         user: Union[AbstractUser, AnonymousUser],
         perms: Union[str, List[str]],
         any_perm: bool = True,
-        checker: Union[ObjectPermissionChecker, None] = None,
+        checker: Union["ObjectPermissionChecker", None] = None,
     ) -> bool:
         """Check if the user has the given permissions to this object.
 
@@ -204,7 +211,17 @@ class GuardedRelatedModel(GuardedModel):
     class Meta:
         abstract = True
 
-    objects = GuardedRelatedManager["GuardedRelatedModel"]()
+    # Make sure objects is properly typed for subclasses
+    if TYPE_CHECKING:
+
+        @classmethod
+        @property
+        def objects(cls: Type[_TR]) -> GuardedRelatedManager[_TR]:
+            ...
+
+    else:
+        objects = GuardedRelatedManager["GuardedRelatedModel"]()
+
     related_model: Union[Type[GuardedModel], str]
     related_attr: str
 
@@ -213,7 +230,7 @@ class GuardedRelatedModel(GuardedModel):
         user: Union[AbstractUser, AnonymousUser],
         perms: Union[str, List[str]],
         any_perm: bool = True,
-        checker: Union[ObjectPermissionChecker, None] = None,
+        checker: Union["ObjectPermissionChecker", None] = None,
     ) -> bool:
         # No guardian means we are not checking perms
         if not has_guardian:
